
$fs = 0.35;
$fa = 0.50;

$str  = 3.0;       // base strength
$str1 = 2.5;       // strength for the smaller sides

$eps  = 0.01;      // epsilon

tolerance = 0.4;

pcb_w     = 50.0 + tolerance;
pcb_h     = 21.5 + tolerance;
pcb_str   =  1.6;
pcb_z_off = 12.0;  // height of transceiver pcb above ground


M2_outer  =  6.5;  // outer diameter for the M2 screw receptacles


// s = socket
s_h = 13;
s_w = pcb_w;


// sc = screw; here: the M2 holes of the PCB
sc_x     = 8.25;
sc_y     = 7.75;
sc_drill = 3.0;


// ph = PinHeader
ph_w     =  7.5;          // enough space for SMD PinHeaders
ph_led_x =  5.7;
ph_485_x = -1.9  - 1.27;
ph_led_l =  11.4 + 1.25;
ph_485_l =  16.5 + 1.25;



module screwPlacement(tz=0) {
  translate([ sc_x, -sc_y, tz]) children();
  translate([-sc_x,  sc_y, tz]) children();
}


module ph_led_placement() {
  translate([ph_led_x,  pcb_h/2 - $str/2, 0]) children();
}

module ph_485_placement() {
  translate([ph_485_x, -pcb_h/2 + $str/2, 0]) children();
}


module border(sy=pcb_z_off, sz=$str1, length=pcb_w, h=pcb_str) {

  translate([-length/2, 0, 0])
    rotate([0, 90, 0])
      linear_extrude(length)
        polygon([
          [-h,  0],
          [sy,  0],
          [-h, sz],
        ]);

}



module PCBSocket() {

  linear_extrude(pcb_z_off) difference() {
    union() {
      difference() {
        square([pcb_w,           pcb_h         ], center=true);
        square([pcb_w - 2*$str1, pcb_h - 2*$str], center=true);
      }

      pll2 = ph_led_l + 2*$str;
      translate([0, $str/2, 0])
        ph_led_placement()
          translate([-pll2/2, -ph_w -0.2, 0])
            square([pll2, ph_w +0.2]);

      p4l2 = ph_485_l + 2*$str;
      translate([0, -$str/2, 0])
        ph_485_placement()
          translate([-p4l2/2, 0.2, 0])
            square([p4l2, ph_w +0.2]);
      
      screwPlacement() circle(d=M2_outer);
    }

    ph_led_placement() square([ph_led_l, ph_w], center=true);
    ph_485_placement() square([ph_485_l, ph_w], center=true);


    screwPlacement() circle(d=sc_drill);
  }


  difference() {
    union() {
      translate([0,  pcb_h/2 -$eps, pcb_z_off]) border();
      translate([0, -pcb_h/2 +$eps, pcb_z_off]) mirror([0, 1, 0]) border();
    }


    ph_led_placement() cube([ph_led_l, 10, 100], center=true);
    ph_485_placement() cube([ph_485_l, 10, 100], center=true);

  }

}


PCBSocket();

